@@ -1,5 +1,5 @@
-# WordNet::Similarity::hso.pm version 0.07
-# (Last updated $Id: hso.pm,v 1.11 2004/10/23 07:23:04 sidz1979 Exp $)
+# WordNet::Similarity::hso.pm version 1.01
+# (Last updated $Id: hso.pm,v 1.13 2005/12/11 22:37:02 sidz1979 Exp $)
 #
 # Semantic Similarity Measure package implementing the measure
 # described by Hirst and St-Onge (1998).
@@ -58,7 +58,7 @@ use vars qw(@ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 
 @EXPORT = ();
 
-our $VERSION = '0.07';
+our $VERSION = '1.01';
 
 sub setPosList
 {
@@ -403,7 +403,7 @@ sub getUpwardOffsetsPOS
 	return @offsets;
     }
     $wordForm = $wn->getSense($offset,$pos);
-    @synsets = $wn->querySense($wordForm, "hype");
+    @synsets = $wn->querySense($wordForm, "hypes");
     push @synsets, $wn->querySense($wordForm, "mero");
     foreach $synset (@synsets)
     {
@@ -449,7 +449,7 @@ sub getDownwardOffsetsPOS
     }
     $wordForm = $wn->getSense($offset,$pos);
     @synsets = $wn->querySense($wordForm, "holo");
-    push @synsets, $wn->querySense($wordForm, "hypo");
+    push @synsets, $wn->querySense($wordForm, "hypos");
     push @synsets, $wn->querySense($wordForm, "enta");
     push @synsets, $wn->querySense($wordForm, "caus");
     foreach $synset (@synsets)
@@ -796,7 +796,7 @@ perl(1), WordNet::Similarity(3), WordNet::QueryData(3)
 
 http://www.cs.utah.edu/~sidd
 
-http://www.cogsci.princeton.edu/~wn
+http://wordnet.princeton.edu
 
 http://www.ai.mit.edu/~jrennie/WordNet
 
@@ -804,19 +804,19 @@ http://groups.yahoo.com/group/wn-similarity
 
 =head1 AUTHORS
 
- Siddharth Patwardhan, University of Utah, Salt Lake City
- sidd at cs.utah.edu
-
  Ted Pedersen, University of Minnesota Duluth
  tpederse at d.umn.edu
 
+ Siddharth Patwardhan, University of Utah, Salt Lake City
+ sidd at cs.utah.edu
+
 =head1 BUGS
 
 None.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2003-2004 by Siddharth Patwardhan and Ted Pedersen
+Copyright (c) 2005, Ted Pedersen and Siddharth Patwardhan
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
