@@ -1,5 +1,5 @@
-# WordNet::Similarity::lesk.pm version 1.01
-# (Last updated $Id: lesk.pm,v 1.24 2005/12/11 22:37:02 sidz1979 Exp $)
+# WordNet::Similarity::lesk.pm version 1.02
+# (Last updated $Id: lesk.pm,v 1.26 2006/02/07 02:52:11 sidz1979 Exp $)
 #
 # Module to accept two WordNet synsets and to return a floating point
 # number that indicates how similar those two synsets are, using an
@@ -55,7 +55,7 @@ use File::Spec;
 use WordNet::Similarity::GlossFinder;
 
 our @ISA = qw(WordNet::Similarity::GlossFinder);
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 
 WordNet::Similarity::addConfigOption ("normalize", 0, "i", 0);
 
@@ -236,7 +236,7 @@ sub getRelatedness
 	}
 	
 	# normalize the function score computed above if required
-	if ($self->{normalize} && ($wc1 * $wc2))
+	if ($self->{normalize} && defined($wc1) && defined($wc2) && ($wc1 * $wc2))
 	{
 	    $functionsScore /= $wc1 * $wc2;
 	}
