@@ -1,16 +1,18 @@
-# stem.pm version 0.03
-# (Updated 03/10/2003 -- Sid)
+# stem.pm version 1.01
+# (Last updated $Id: stem.pm,v 1.6 2005/12/11 22:37:02 sidz1979 Exp $)
 #
 # Package used by WordNet::Similarity::lesk module that
 # computes semantic relatedness of word senses in WordNet
 # using gloss overlaps.
 #
-# Copyright (c) 2003,
-# Satanjeev Banerjee, Carnegie Mellon University, Pittsburgh
-# banerjee+ at cs.cmu.edu
+# Copyright (c) 2005,
+#
 # Ted Pedersen, University of Minnesota Duluth
 # tpederse at d.umn.edu
 #
+# Satanjeev Banerjee, Carnegie Mellon University, Pittsburgh
+# banerjee+ at cs.cmu.edu
+#
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
 # as published by the Free Software Foundation; either version 2
@@ -27,6 +29,8 @@
 # The Free Software Foundation, Inc., 
 # 59 Temple Place - Suite 330, 
 # Boston, MA  02111-1307, USA.
+#
+# ------------------------------------------------------------------
 
 package stem;
 
@@ -44,7 +48,7 @@ use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 
 @EXPORT = ();
 
-$VERSION = '0.03';
+$VERSION = '1.01';
 
 # function to set up the wordnet object.
 sub new
@@ -53,9 +57,9 @@ sub new
     my $wn = shift;
     my $self = {};
 
-    $self->{'wn'} = $wn;
-    $self->{'wordStemHash'} = ();
-    $self->{'stringStemHash'} = ();
+    $self->{wn} = $wn;
+    $self->{wordStemHash} = ();
+    $self->{stringStemHash} = ();
     bless($self, $className);
 
     return $self;
@@ -108,11 +112,11 @@ sub stemWord
 {
     my $self = shift;
     my $word = shift;
-    my $wn = $self->{'wn'};
+    my $wn = $self->{wn};
     my @stems = ();
     
     # if not in the cache, create and put in cache
-    if (!defined $self->{'wordStemHash'}->{$word})
+    if (!defined $self->{wordStemHash}->{$word})
     {
 	# So not in the hash. gotta check for all possible parts of speech.
 	my %stems = ();
@@ -136,11 +140,11 @@ sub stemWord
 	}
 	
 	# put in the cache
-	$self->{'wordStemHash'}->{$word} = join(" ", (keys %stems));
+	$self->{wordStemHash}->{$word} = join(" ", (keys %stems));
     }
     
     # return the stems
-    return (split / /, $self->{'wordStemHash'}->{$word});
+    return (split / /, $self->{wordStemHash}->{$word});
 }
 
 1;
